@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 21968 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 10:40:38 +0000 (Wed, 04 Jun 2008) $
+ * $Date: 2009-01-30 23:02:45 +0000 (Fri, 30 Jan 2009) $
  */
 
 #include <ptlib.h>
@@ -91,6 +91,9 @@ PBoolean PPipeChannel::PlatformOpen(const PString & subProgram,
     envStr = envBuf.GetPointer();
   }
 
+  //
+  // this code comes from http://msdn.microsoft.com/en-us/library/ms682499(VS.85).aspx
+  //
   STARTUPINFO startup;
   memset(&startup, 0, sizeof(startup));
   startup.cb = sizeof(startup);
@@ -103,18 +106,24 @@ PBoolean PPipeChannel::PlatformOpen(const PString & subProgram,
   SECURITY_ATTRIBUTES security;
   security.nLength = sizeof(security);
   security.lpSecurityDescriptor = NULL;
-  security.bInheritHandle = PTrue;
+  security.bInheritHandle = TRUE;
 
+  // ReadOnly means child has no stdin
+  // otherwise create a pipe for us to send data to child
   if (mode == ReadOnly)
     hToChild = INVALID_HANDLE_VALUE;
   else {
     HANDLE writeEnd;
     PAssertOS(CreatePipe(&startup.hStdInput, &writeEnd, &security, 0));
+    PAssertOS(SetHandleInformation(writeEnd, HANDLE_FLAG_INHERIT, 0));
     PAssertOS(DuplicateHandle(GetCurrentProcess(), writeEnd,
                               GetCurrentProcess(), &hToChild, 0, PFalse,
                               DUPLICATE_CLOSE_SOURCE|DUPLICATE_SAME_ACCESS));
   }
 
+  // WriteOnly means child has no stdout
+  // ReadWriteStd means child uses our stdout and stderr
+  // otherwise, create a pipe to read stdout from child, and perhaps a seperate one for stderr too
   if (mode == WriteOnly)
     hFromChild = INVALID_HANDLE_VALUE;
   else if (mode == ReadWriteStd) {
@@ -123,9 +132,14 @@ PBoolean PPipeChannel::PlatformOpen(const PString & subProgram,
     startup.hStdError = GetStdHandle(STD_ERROR_HANDLE);
   }
   else {
-    PAssertOS(CreatePipe(&hFromChild, &startup.hStdOutput, &security, 0));
-    if (stderrSeparate)
-      PAssertOS(CreatePipe(&hStandardError, &startup.hStdError, &security, 0));
+    PAssertOS(CreatePipe(&hFromChild, &startup.hStdOutput, &security, 128000));
+    PAssertOS(SetNamedPipeHandleState(&hFromChild, PIPE_READMODE_BYTE, NULL, NULL));
+    PAssertOS(SetHandleInformation(hFromChild, HANDLE_FLAG_INHERIT, 0));
+    if (stderrSeparate) {
+      PAssertOS(CreatePipe(&hStandardError, &startup.hStdError, &security, 128000));
+      PAssertOS(SetNamedPipeHandleState(&hStandardError, PIPE_READMODE_BYTE, NULL, NULL));
+      PAssertOS(SetHandleInformation(hStandardError, HANDLE_FLAG_INHERIT, 0));
+    }
     else {
       startup.hStdError = startup.hStdOutput;
       hStandardError = INVALID_HANDLE_VALUE;
