@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20916 $
- * $Author: rjongbloed $
- * $Date: 2008-09-10 05:46:05 +0000 (Wed, 10 Sep 2008) $
+ * $Revision: 21884 $
+ * $Author: csoutheren $
+ * $Date: 2009-01-05 04:26:54 +0000 (Mon, 05 Jan 2009) $
  */
 
 #include <ptlib.h>
@@ -48,6 +48,10 @@
 #include <ptlib/wm/mmsystemx.h>
 #endif
 
+namespace PWLibStupidLinkerHacks {
+   int loadWindowsMultimediaStuff;
+};
+     
 class PSound;
 
 PCREATE_SOUND_PLUGIN(WindowsMultimedia, PSoundChannelWin32);
@@ -605,6 +609,7 @@ PSoundChannelWin32::PSoundChannelWin32(const PString & device,
 
 void PSoundChannelWin32::Construct()
 {
+  opened = false;
   direction = Player;
   hWaveOut = NULL;
   hWaveIn = NULL;
@@ -836,13 +841,14 @@ PBoolean PSoundChannelWin32::OpenDevice(unsigned id)
     }
   }
 
+  opened = true;
   os_handle = id;
   return PTrue;
 }
 
 PBoolean PSoundChannelWin32::IsOpen() const
 { 
-  return os_handle >= 0;
+  return opened ? PTrue : PFalse;
 }
 
 PBoolean PSoundChannelWin32::SetFormat(unsigned numChannels,
@@ -911,6 +917,7 @@ PBoolean PSoundChannelWin32::Close()
     hMixer = NULL;
   }
 
+  opened = false;
   os_handle = -1;
   return PTrue;
 }
@@ -1440,7 +1447,7 @@ PBoolean PSoundChannelWin32::GetVolume(unsigned & oldVolume)
   details.cbDetails = sizeof(volume);
   details.paDetails = &volume;
 
-  MMRESULT result = mixerSetControlDetails((HMIXEROBJ)hMixer, &details, MIXER_OBJECTF_HMIXER | MIXER_SETCONTROLDETAILSF_VALUE);
+  MMRESULT result = mixerSetControlDetails((HMIXEROBJ)hMixer, &details, MIXER_OBJECTF_HMIXER | MIXER_GETCONTROLDETAILSF_VALUE);
   if (result != MMSYSERR_NOERROR)
     return SetErrorValues(Miscellaneous, result|PWIN32ErrorFlag);
 
