@@ -23,9 +23,9 @@
  *
  * Contributor(s): Matthias Schneider <ma30002000@yahoo.de>
  *
- * $Revision: 21828 $
+ * $Revision: 22051 $
  * $Author: rjongbloed $
- * $Date: 2008-12-18 00:11:03 +0000 (Thu, 18 Dec 2008) $
+ * $Date: 2009-02-12 06:27:44 +0000 (Thu, 12 Feb 2009) $
  */
 
 #include <ptlib.h>
@@ -42,7 +42,7 @@
 #pragma comment(lib, P_DIRECTSHOW_LIBRARY2)
 #endif
 
-#if defined(P_MINGW)
+#if defined(P_MINGW) || defined(_WIN32) || defined(P_MACOSX)
 namespace PWLibStupidLinkerHacks {
   int loadDirectShowStuff;
 };
